@@ -1,4 +1,3 @@
-# $Id: IdentServer.pm,v 1.42 2005/05/07 18:05:13 jettero Exp $
 
 package Net::IdentServer;
 
@@ -6,111 +5,17 @@ use strict;
 use warnings;
 use POSIX;
 use Carp;
-use Config::IniFiles;
-
-# This should totally be configurable... this was a completely arbitrary choice!
 use base qw(Net::Server::Fork);
-# /choice
 
-our $REVISION = q($Revision: 1.42 $); $REVISION =~ s/[^\.\d]//g; $REVISION =~ s/^1\.//;
-our $VERSION  = "0.56";
+our $VERSION  = "0.601";
 
 1;
 
-# read_config {{{
-sub read_config {
-    my $this = shift; 
-    my $conf = shift;
-    
-    croak "please call new() first " . ref($this) unless ref($this);
-
-    return $this->{conf} if defined $this->{conf};
-
-    my %ini;
-
-    my @configs = ("/etc/identserver.ini", "/etc/identserver/identserver.ini", "./identserver.ini");
-
-    warn "no config files found or specified\n" unless @configs > 0;
-    for my $file (@configs) {
-        if( not $conf->{shhh} and $file =~ m/^\.\// ) {
-            warn "WARNING: You are reading an ini file located in ./";
-            sleep 1;
-        }
-        if( open IN, $file ) {
-            if( my $cfg = new Config::IniFiles( -file => *IN ) ) {
-                for my $s ($cfg->Sections) {
-                    for my $p ( $cfg->Parameters($s) ) {
-                        $ini{$s}{$p} = $cfg->val($s, $p);
-                    }
-                }
-            }
-            close IN;
-
-        } elsif( -f $file ) {
-            warn "config file named $file found, but could not be opened: $!\n";
-
-        }
-    }
-
-    for my $k (keys %$conf) {
-        $ini{server}{$k} = $conf->{$k};
-    }
-
-    my @must_def = qw(log_level log_file pid_file allow port);
-
-    my $def = 1; 
-       $def = ($def and defined $ini{server}{$_}) for @must_def;
-
-    unless( $def ) {
-        print STDERR "Unable to read config or did not find the minimum settings there.\n";
-        print STDERR "All of the following must be defined in the server section:\n";
-        print STDERR "\t$_\n" for @must_def;
-        exit 1;
-    }
-
-    $this->{conf} = \%ini;
-
-    return $this->{conf};
-}
-# }}}
-
-# new {{{
-sub new {
-    my $class = shift;
-    my $this  = bless {}, $class;
-    my $conf  = { @_ };
-
-    $this->read_config($conf);
-
-    return $this;
-}
-# }}}
 # run {{{
 sub run {
     my $this = shift;
-
-    local @ARGV = ();
-
-    $0 = "identd";
-
-    $this->SUPER::run( map(($_ => $this->{conf}{server}{$_}), keys %{ $this->{conf}{server} }) );
-}
-# }}}
-# log {{{
-sub log {
-    my $this    = shift;
-    my ($l, $m) = @_;
-
-    $m =~ s/^\s+//; $m =~ s/\s+$//; $m =~ s/[\r\n]//msg;
-    $m =~ s/^\d{4}\/\d{2}\/\d{2}\-\d{2}\:\d{2}\:\d{2} //;
-
-    if( $l > 3 ) {
-        $m = "[DEBUG] $m";
-    }
-
-    $m = strftime('%Y-%m-%d %H:%M:%S ', localtime) . sprintf('%7s: %s', "[$$]", $m);
-
-    $this->SUPER::log($l, "$m\n");
+    $0 = ref $this;
+    $this->SUPER::run( @_ );
 }
 # }}}
 
@@ -135,7 +40,7 @@ sub print_response {
 
     $os_name = "USERID : $os_name" unless $os_name eq "ERROR";
 
-    printf '%d , %d : %s : %s'."\r\n", $port_on_server, $port_on_client, $os_name, $add_info;
+    printf '%d , %d : %s : %s'."\x0d\x0a", $port_on_server, $port_on_client, $os_name, $add_info;
 }
 # }}}
 # do_lookup {{{
@@ -158,8 +63,8 @@ sub do_lookup {
     }
 
     if( $found < 0 ) {
-        open TCP, "/proc/net/tcp" or die "couldn't open proc/net/tcp for read: $!";
-        while(<TCP>) {
+        open my $tcp, "<", "/proc/net/tcp" or die "couldn't open proc/net/tcp for read: $!";
+        while(<$tcp>) {
             if( m/^\s+\d+:\s+([A-F0-9]{8}):([A-F0-9]{4})\s+([A-F0-9]{8}):([A-F0-9]{4})\s+(\d+)\s+\S+\s+\S+\s+\S+\s+(\d+)/ ) {
                 my ($la, $lp, $ra, $rp, $state, $uid) = ($1, $2, $3, $4, $5, $6);
 
@@ -174,7 +79,7 @@ sub do_lookup {
                 }
             }
         }
-        close TCP;
+        close $tcp;
     }
 
     if( $found < 0 ) {
@@ -218,12 +123,12 @@ sub alt_lookup {
 sub process_request {
     my $this = shift;
 
-    my $master_alarm = alarm ($this->{conf}{server}{timeout}>0 ? $this->{conf}{server}{timeout} : 10);
+    my $master_alarm = alarm 10;
     local $SIG{ALRM} = sub { die "\n" };
     eval {
         while( my $input = <STDIN> ) {
            $input = "" unless $input; # to deal with stupid undef warning
-           $input =~ s/[\r\n]//sg;
+           $input =~ s/[\x0d\x0a]+\z//;
 
             unless( $input =~ m/^\s*(\d+)\s*,\s*(\d+)\s*$/ ) {
                 $this->log(3, "Malformated request from $this->{server}{peeraddr}");
@@ -249,36 +154,36 @@ sub process_request {
 # }}}
 
 __END__
-# Below is stub documentation for your module. You better edit it!
 
+=encoding UTF-8
 =head1 NAME
 
-Net::IdentServer - An rfc 1413 Ident server which @ISA [is a] Net::Server.
+Net::IdentServer - An rfc 1413 Ident server using L<Net::Server::Fork>.
 
 =head1 SYNOPSIS
 
-use Net::IdentServer;
+    use Net::IdentServer;
 
-my $nis = new Net::IdentServer;
+    my $nis = Net::IdentServer->new();
 
-run $nis;  # This is a working identd ...
+    run $nis;
+    # This is a working identd …
+    # though, you probably need to be root
 
 =head1 DESCRIPTION
 
 Although you can run this as you see in the SYNOPSIS, you'll
 probably want to rewrite a few things.
 
-Net::IdentServer is a child of Net::Server to be sure.  If
-you wish to override the behaviours of this module, just
-inherit it and start re-writing as you go.  
+L<Net::IdentServer> inherits L<Net::Server>, so click through
+to that module for a description of the arguments to new() and
+for how it reads @ARGV.
 
 An example random fifteen-letter-word ident server follows:
 
-    use strict;
+    package main;
 
-    my $s = new RandomIdentServer;
-
-    run $s;
+    RandomIdentServer->new( user=>'nobody', group=>'nobody' )->run;
 
     package RandomIdentServer;
 
@@ -328,27 +233,25 @@ An example random fifteen-letter-word ident server follows:
 
 =head2 print_response
 
-See the DESCRIPTION for an actual example.  This is the function that
-prints the reponse to the client.  As arguments, it receives $local port,
-$remote port, result $os_name (in caps) and the extended $info (usually a
-username or error).
+See the L<DESCRIPTION> for an actual example.  This is the function that prints
+the reponse to the client.  As arguments, it receives $local port, $remote
+port, result $os_name (in caps) and the extended $info (usually a username or
+error).
 
 =head2 alt_lookup
 
-There exists a function that receives $local_addr,
-$local_port, $rem_addr, and $rem_port as arguments.
-Confusingly, the $local_addr and $rem_addr refer to the
-present socket connection, and the $local_port and $rem_port
-refer to the ports being queried.
+∃ a function that receives $local_addr, $local_port, $rem_addr, and $rem_port
+as arguments.  Confusingly, the $local_addr and $rem_addr refer to the present
+socket connection, and the $local_port and $rem_port refer to the ports being
+queried.
 
-You can do whatever lookups you like on this data and return
-a $uid.  If you return a negative $uid, do_lookup will
-perform the standard lookup.
+You can do whatever lookups you like on this data and return a $uid.  If you
+return a negative $uid, do_lookup will perform the standard lookup.
 
 The default alt_lookup just returns a -1.
 
-Lastly, if you return a string that matches m/^JP:(.+)/,
-then $1 will be printed as the username.
+Lastly, if you return a string that matches m/^JP:(.+)/, then $1 will be
+printed as the username.
 
 Example:
 
@@ -392,54 +295,40 @@ function entirely.  But otherwise picking something besides
 the four examples shown will earn you an error and an
 exit(1).
 
-=head1 $this->{conf}
-
-The entire ini file is stored in your server object.  Each section is 
-it's own hash key and each value is a key of the section.
-
-Example:  $this->{conf}{server}{port} 
-
-This is the port listed under the server section of your ini file.
-
 =head1 AUTHOR
 
-Jettero Heller <japh@voltar-confed.org>
+Paul Miller C<< <jettero@cpan.org> >>
 
-Jet is using this software in his own projects...  If you find
-bugs, please please please let him know. :) Actually, let him
-know if you find it handy at all.  Half the fun of releasing this
-stuff is knowing that people use it.
-
-Additionally, he is aware that the documentation sucks.  Should
-you email him for help, he will most likely try to give it.
+I'm using this in my own projects.  If you like it or hate me or something,
+drop me a line.  I usually answer my email.
 
 =head1 COPYRIGHT
 
-GPL!  I included a gpl.txt for your reading enjoyment.
+© 2014 Paul Miller
 
-Though, additionally, I will say that I'll be tickled if you
-were to include this package in any commercial endeavor.
-Also, any thoughts to the effect that using this module will
-somehow make your commercial package GPL should be washed
-away.
+=head1 BUGS
 
-I hereby release you from any such silly conditions.
+Of course. But lemme know what they are?
 
-This package and any modifications you make to it must
-remain GPL.  Any programs you (or your company) write shall
-remain yours (and under whatever copyright you choose) even
-if you use this package's intended and/or exported
-interfaces in them.
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Net::IdentServer>
 
-=head1 SPECIAL THANKS
+(maybe the name is one? Net::Ident::Server maybe? meh…)
 
-Holy smokes, Net::Server is the shizzo fo shizzo.  Everyone
-send a blessing to this guy, seriously.
+There's no way this old code works with IPv6 ... it reads several bytes from
+/proc/net/somewhere and probably the whole mess needs to be redone.
 
-Paul T. Seamons <paul at seamons.com>
+=head1 LICENSE
+
+Perl Artisitic License — use this like any other Perl thing.
+
+(This was previously licensed under GPL v2, assume that's still the case if you
+like.)
 
 =head1 SEE ALSO
 
-perl(1), Net::Server
+Consider using L<POE::Component::Server::Ident>. I haven't personally checked
+it out, but BINGOS wrote it so it's probably a better choice than this.
+
+perl(1), L<Net::Server>, L<http://www.ietf.org/rfc/rfc1413.txt>
 
 =cut
